==> jupyterlite_p5_kernel-0.1.0.tar.gz: jupyterlite_p5_kernel-0.1.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.0

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/f45a8d32cbae40472fa1e0a0e9fcc8351486005b...27da1b9b7087582dde632dfb2627e45e615733f1))

### New features added

- Switch to a federated serverlite extension [#1](https://github.com/jupyterlite/p5-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Enhancements made

- Update P5.js to version 1.4.2 [#15](https://github.com/jupyterlite/p5-kernel/pull/15) ([@M0JPI](https://github.com/M0JPI))
- Handle updating display data [#11](https://github.com/jupyterlite/p5-kernel/pull/11) ([@jtpio](https://github.com/jtpio))

### Bugs fixed

- Fix handling of the logo [#9](https://github.com/jupyterlite/p5-kernel/pull/9) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Various maintenance tasks [#18](https://github.com/jupyterlite/p5-kernel/pull/18) ([@jtpio](https://github.com/jtpio))
- Fix links to the GitHub repo [#5](https://github.com/jupyterlite/p5-kernel/pull/5) ([@jtpio](https://github.com/jtpio))
- Use consistent naming for the lab extension [#4](https://github.com/jupyterlite/p5-kernel/pull/4) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add JupyterLite badge in the README.md [#20](https://github.com/jupyterlite/p5-kernel/pull/20) ([@jtpio](https://github.com/jtpio))
- Add config files for ReadTheDocs [#19](https://github.com/jupyterlite/p5-kernel/pull/19) ([@jtpio](https://github.com/jtpio))
- DOC: README.md: links, capitalization [#13](https://github.com/jupyterlite/p5-kernel/pull/13) ([@westurner](https://github.com/westurner))
- changed readme [#7](https://github.com/jupyterlite/p5-kernel/pull/7) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-09-29&to=2023-01-21&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Abollwyvl+updated%3A2021-09-29..2023-01-21&type=Issues) | [@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3ADerThorsten+updated%3A2021-09-29..2023-01-21&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-09-29..2023-01-21&type=Issues) | [@M0JPI](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3AM0JPI+updated%3A2021-09-29..2023-01-21&type=Issues) | [@westurner](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Awesturner+updated%3A2021-09-29..2023-01-21&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.0a12

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/v0.1.0a11...a14b3b80924870e6eac71dd1982594df1cb102a2))

### Bugs fixed

- Fix handling of the logo [#9](https://github.com/jupyterlite/p5-kernel/pull/9) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- changed readme [#7](https://github.com/jupyterlite/p5-kernel/pull/7) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-10-01&to=2021-10-14&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3ADerThorsten+updated%3A2021-10-01..2021-10-14&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-10-01..2021-10-14&type=Issues)

## 0.1.0a11

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/@jupyterlite/p5-kernel-extension@0.1.0-alpha.10...16bed8258f82806a188f070ee8024b16228dfdd4))

### Maintenance and upkeep improvements

- Fix links to the GitHub repo [#5](https://github.com/jupyterlite/p5-kernel/pull/5) ([@jtpio](https://github.com/jtpio))
- Use consistent naming for the lab extension [#4](https://github.com/jupyterlite/p5-kernel/pull/4) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-09-30&to=2021-10-01&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-09-30..2021-10-01&type=Issues)

## 0.1.0a10

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/first-commit...b91d19f351a4e130a446bb45e0715d29aca24666))

### New features added

- Switch to a federated serverlite extension [#1](https://github.com/jupyterlite/p5-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-09-29&to=2021-09-30&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Abollwyvl+updated%3A2021-09-29..2021-09-30&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-09-29..2021-09-30&type=Issues)

## 0.0.1

Initial Version

==> jupyterlite_p5_kernel-0.1.1.tar.gz: jupyterlite_p5_kernel-0.1.1/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.1

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/@jupyterlite/p5-kernel-extension@0.1.0...3dd4b3c779cdb12f4dde130eab2f6c95f9530e97))

### Maintenance and upkeep improvements

- Update to p5 1.5.0 [#23](https://github.com/jupyterlite/p5-kernel/pull/23) ([@jtpio](https://github.com/jtpio))
- Add releaser workflows [#22](https://github.com/jupyterlite/p5-kernel/pull/22) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Use `mamba` to activate the environment [#21](https://github.com/jupyterlite/p5-kernel/pull/21) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2023-01-21&to=2023-02-10&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Agithub-actions+updated%3A2023-01-21..2023-02-10&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2023-01-21..2023-02-10&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.0

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/f45a8d32cbae40472fa1e0a0e9fcc8351486005b...27da1b9b7087582dde632dfb2627e45e615733f1))

### New features added

- Switch to a federated serverlite extension [#1](https://github.com/jupyterlite/p5-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Enhancements made

- Update P5.js to version 1.4.2 [#15](https://github.com/jupyterlite/p5-kernel/pull/15) ([@M0JPI](https://github.com/M0JPI))
- Handle updating display data [#11](https://github.com/jupyterlite/p5-kernel/pull/11) ([@jtpio](https://github.com/jtpio))

### Bugs fixed

- Fix handling of the logo [#9](https://github.com/jupyterlite/p5-kernel/pull/9) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Various maintenance tasks [#18](https://github.com/jupyterlite/p5-kernel/pull/18) ([@jtpio](https://github.com/jtpio))
- Fix links to the GitHub repo [#5](https://github.com/jupyterlite/p5-kernel/pull/5) ([@jtpio](https://github.com/jtpio))
- Use consistent naming for the lab extension [#4](https://github.com/jupyterlite/p5-kernel/pull/4) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add JupyterLite badge in the README.md [#20](https://github.com/jupyterlite/p5-kernel/pull/20) ([@jtpio](https://github.com/jtpio))
- Add config files for ReadTheDocs [#19](https://github.com/jupyterlite/p5-kernel/pull/19) ([@jtpio](https://github.com/jtpio))
- DOC: README.md: links, capitalization [#13](https://github.com/jupyterlite/p5-kernel/pull/13) ([@westurner](https://github.com/westurner))
- changed readme [#7](https://github.com/jupyterlite/p5-kernel/pull/7) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-09-29&to=2023-01-21&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Abollwyvl+updated%3A2021-09-29..2023-01-21&type=Issues) | [@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3ADerThorsten+updated%3A2021-09-29..2023-01-21&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-09-29..2023-01-21&type=Issues) | [@M0JPI](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3AM0JPI+updated%3A2021-09-29..2023-01-21&type=Issues) | [@westurner](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Awesturner+updated%3A2021-09-29..2023-01-21&type=Issues)

## 0.1.0a12

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/v0.1.0a11...a14b3b80924870e6eac71dd1982594df1cb102a2))

### Bugs fixed

- Fix handling of the logo [#9](https://github.com/jupyterlite/p5-kernel/pull/9) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- changed readme [#7](https://github.com/jupyterlite/p5-kernel/pull/7) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-10-01&to=2021-10-14&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3ADerThorsten+updated%3A2021-10-01..2021-10-14&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-10-01..2021-10-14&type=Issues)

## 0.1.0a11

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/@jupyterlite/p5-kernel-extension@0.1.0-alpha.10...16bed8258f82806a188f070ee8024b16228dfdd4))

### Maintenance and upkeep improvements

- Fix links to the GitHub repo [#5](https://github.com/jupyterlite/p5-kernel/pull/5) ([@jtpio](https://github.com/jtpio))
- Use consistent naming for the lab extension [#4](https://github.com/jupyterlite/p5-kernel/pull/4) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-09-30&to=2021-10-01&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-09-30..2021-10-01&type=Issues)

## 0.1.0a10

([Full Changelog](https://github.com/jupyterlite/p5-kernel/compare/first-commit...b91d19f351a4e130a446bb45e0715d29aca24666))

### New features added

- Switch to a federated serverlite extension [#1](https://github.com/jupyterlite/p5-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/p5-kernel/graphs/contributors?from=2021-09-29&to=2021-09-30&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Abollwyvl+updated%3A2021-09-29..2021-09-30&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fp5-kernel+involves%3Ajtpio+updated%3A2021-09-29..2021-09-30&type=Issues)

## 0.0.1

Initial Version
